==> yuichat-p-0.2b.tar.gz: yuichat-p/setup/create.sql <==
--
-- 椤äPostgreSQL+PHP4 
-- $Id: create.sql,v 1.6 2002/09/17 07:53:42 nanasess Exp $
--

-- Ͽơ֥
DROP TABLE chat_log;
DROP SEQUENCE chat_log_count_seq;
CREATE TABLE chat_log (
		count serial8, -- PostgreSQL 7.2 ΥСξserialȤȡ
		name varchar(32), -- ϥɥ͡
		email varchar(128), -- e-mail
		color varchar(32) DEFAULT '#FF0000', -- ̾ο
		log_color varchar(32), -- ʸ
		log_size varchar(32), -- ʸ
		log_bold bool DEFAULT 't', -- ɽ
		timerec timestamp DEFAULT now(), -- 
		log_agent varchar(128), -- HTTP_USER_AGENT
		log_host varchar(256), -- ۥ̾IPɥ쥹
		log varchar(512), -- 
		views bool DEFAULT 't' -- ɽ/ɽե饰
);

-- ¤Ϳ롣桼̾apacheˤʬWebСμ¹ԥ桼ˤ뤳ȡnobodyǤ뤳Ȥ¿
GRANT SELECT, INSERT ,UPDATE ON chat_log TO apache;
GRANT SELECT, UPDATE ON chat_log_count_seq TO apache;

-- üɽơ֥
DROP TABLE chat_sanka;
CREATE TABLE chat_sanka (
		name varchar(32), -- ϥɥ͡
		color varchar(32), -- ʸ
		host varchar(256), -- ۥ̾IPɥ쥹
		agent varchar(128), -- HTTP_USER_AGENT
		timerec timestamp DEFAULT now(), -- û
		flags bool DEFAULT 't' -- ɽ/ɽե饰
		);

-- ¤Ϳ롣桼̾apacheˤʬWebСμ¹ԥ桼ˤ뤳ȡnobodyǤ뤳Ȥ¿
GRANT SELECT, INSERT, UPDATE, DELETE ON chat_sanka TO apache;

-- üΥơ֥
DROP TABLE chat_comer;
DROP SEQUENCE chat_comer_count_seq;
CREATE TABLE chat_comer (
		count serial8, -- PostgreSQL 7.2 ΥСξserialȤȡ
		name varchar(32), -- ϥɥ͡
		color varchar(32), -- ̾ο
		timerec timestamp DEFAULT now() -- 
		);

-- ¤Ϳ롣桼̾apacheˤʬWebСμ¹ԥ桼ˤ뤳ȡnobodyǤ뤳Ȥ¿
GRANT SELECT, INSERT, UPDATE ON chat_comer TO apache;
GRANT SELECT, UPDATE ON chat_comer_count_seq TO apache;

-- ʸơ֥
DROP TABLE color;
CREATE TABLE color (
	color_name text NOT NULL,
	color_hex text NOT NULL
);

-- ¤Ϳ롣桼̾(apache)ʬWebСμ¹ԥ桼ˤ뤳ȡ(nobody)Ǥ뤳Ȥ¿)
GRANT SELECT ON color TO apache;

COPY color FROM '/home/nanasess/public_html/yuichat-p/setup/color.txt';

==> yuichat-p-0.3b-p1.tar.gz: yuichat-p/setup/create.sql <==
--
-- 椤äPostgreSQL+PHP4 
-- $Id: create.sql,v 1.1.1.2 2003/01/09 11:20:57 nanasess Exp $
--

-- Ͽơ֥
DROP TABLE chat_log;
DROP SEQUENCE chat_log_count_seq;
CREATE TABLE chat_log (
		count serial8, -- PostgreSQL 7.2 ΥСξserialȤȡ
		name text, -- ϥɥ͡
		email varchar(128), -- e-mail
		color varchar(32) DEFAULT '#FF0000', -- ̾ο
		log_color varchar(32), -- ʸ
		log_size varchar(32), -- ʸ
		log_bold bool DEFAULT 't', -- ɽ
		timerec timestamp DEFAULT now(), -- 
		log_agent text, -- HTTP_USER_AGENT
		log_host text, -- ۥ̾IPɥ쥹
		log text, -- 
		views bool DEFAULT 't' -- ɽ/ɽե饰
);

-- ¤Ϳ롣桼̾apacheˤʬWebСμ¹ԥ桼ˤ뤳ȡnobodyǤ뤳Ȥ¿
GRANT SELECT, INSERT ,UPDATE ON chat_log TO apache;
GRANT SELECT, UPDATE ON chat_log_count_seq TO apache;

-- üɽơ֥
DROP TABLE chat_sanka;
CREATE TABLE chat_sanka (
		name text, -- ϥɥ͡
		color varchar(32), -- ʸ
		host text, -- ۥ̾IPɥ쥹
		agent text, -- HTTP_USER_AGENT
		timerec timestamp DEFAULT now(), -- û
		flags bool DEFAULT 't' -- ɽ/ɽե饰
		);

-- ¤Ϳ롣桼̾apacheˤʬWebСμ¹ԥ桼ˤ뤳ȡnobodyǤ뤳Ȥ¿
GRANT SELECT, INSERT, UPDATE, DELETE ON chat_sanka TO apache;

-- üΥơ֥
DROP TABLE chat_comer;
DROP SEQUENCE chat_comer_count_seq;
CREATE TABLE chat_comer (
		count serial8, -- PostgreSQL 7.2 ΥСξserialȤȡ
		name text, -- ϥɥ͡
		color varchar(32), -- ̾ο
		timerec timestamp DEFAULT now() -- 
		);

-- ¤Ϳ롣桼̾apacheˤʬWebСμ¹ԥ桼ˤ뤳ȡnobodyǤ뤳Ȥ¿
GRANT SELECT, INSERT, UPDATE ON chat_comer TO apache;
GRANT SELECT, UPDATE ON chat_comer_count_seq TO apache;

-- ʸơ֥
DROP TABLE color;
CREATE TABLE color (
	color_name text NOT NULL,
	color_hex text NOT NULL
);

-- ¤Ϳ롣桼̾(apache)ʬWebСμ¹ԥ桼ˤ뤳ȡ(nobody)Ǥ뤳Ȥ¿)
GRANT SELECT ON color TO apache;

COPY color FROM '/home/nanasess/public_html/yuichat-p/setup/color.txt';
